# -*- coding: utf-8 -*-
"""
Created on Sat Apr  8 16:29:23 2023

@author: Mathieu Cancade
"""
import numpy as np

import matplotlib.pyplot as plt
from scipy.integrate import odeint

def pendule_simple(theta_thetapoint, t):
    theta, theta_point = theta_thetapoint
    return [theta_point, -np.sin(theta)]

theta_thetapoint = (np.pi / 3, 0)
t = np.linspace(0, 5 * np.pi, 1000)
sol = odeint(pendule_simple, (np.pi/3, 0), t)

theta, theta_point = sol.T

E_cin = (1./2)*theta_point**2

E_pot = 1 - np.cos(theta)

E_meca = E_cin+E_pot

plt.figure()
ax = plt.gca()
plt.plot(t, E_cin, 'o-', lw=2, label=u'$E_\mathrm{cin}$')
plt.plot(t, E_pot, 'o-', lw=2, label=u'$E_\mathrm{pot}$')
plt.plot(t, E_meca, lw=2, label=u'$E_\mathrm{meca}$')
plt.xticks(np.pi * np.arange(5), [0, u'$\pi$', u'$2\pi$', u'$3\pi$', u'$4\pi$'])
plt.xlabel(u'$t$', fontsize=26)
plt.title(u'Conservation de l\'énergie (pendule simple, sans frottements)')
plt.gca().tick_params(axis='both', which='major', labelsize=20)
plt.legend(loc='best')
plt.grid()
plt.show()

